<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Http\Request;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\DB;
use Laravel\Sanctum\HasApiTokens;
use modules\location\Models\Location;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'location_id'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    public function location() {
        return $this->belongsTo(Location::class, 'location_id');
    }

    public function users(array $data = []){
        $res = DB::table("users")
                    ->select("users.*", "roles.name as permission", "locations.title as location")
                    ->join("roles", "roles.id", "=", "users.permission_id")
                    ->leftJoin("locations", "locations.id", "=", "users.location_id");

        if(!empty($data)){
            if(isset($data["id"])){
                $res->where("users.id", $data["id"]);
            }
        }

        $users = $res->get();        
        return $users;
    }

    public function insertdata(Request $request)
    {
        $data = $request->all();        
        $insert = [
            'location_id' => (int)$data['location']['id'] == 0 ? null : $data['location']['id'],
            "name" => $data['name'],            
            "email" => $data['email'],            
            "password" => bcrypt($data['password']),
            "permission_id" => $data['permission_id']['id'],            
            "created_at" => date_now(),
            "updated_at" => date_now(),
        ];        
        $id = DB::table("users")->insertGetId($insert);

        $user = User::find($id);
        $user->assignRole(Role::find($data['permission_id']['id']));

        return $user;
    }

    public function updatedata(Request $request)
    {
        $data = $request->all();
        $id = $request->id;
        
        DB::table("users")->where("id", $id)->update([
            'location_id' => (int)$data['location']['id'] == 0 ? null : $data['location']['id'],
            "name" => $data['name'],            
            "permission_id" => $data['permission_id']['id'],
            "email" => $data['email'],                  
            "updated_at" => date_now(),
        ]);

        if((int)$request->password != "********"){
            DB::table("users")->where("id", $id)->update([
                "password" => bcrypt($data['password']),
            ]);
        }

        $user = User::find($id);        
        $user->assignRole(Role::find($data['permission_id']['id']));
        
        return $user;
    }
}
