<?php

namespace modules\catalogs\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use modules\location\Models\Location;
use modules\stocks\Models\Inventory;
use modules\stocks\Models\InventoryDetail;
use modules\stocks\Models\StockStory;

class Products extends Model
{
    use HasFactory;
    
    protected $table = "products";
    protected $fillable = [
        'title',
        'type',
        'reference',
        'numero',
        'barcode',
        'image',
        'status',
        'description',
        'unite_id',
        'unite',
        'username',
        'stock_management',
        'is_tva_inclusive',
        'purchase_price', //prix d'achat
        'tva_rate',
        'price',
        'expiration_date',
        'reorder_level',
        'position',
        'background',
        'color',
        'slug',        
        'price_variant',
        'cost_price', //prix de revient
        'cmup',
        'frns_id',
        'frns',
        'frns_is_tva_inclusive',
        'frns_tva',
        'frns_price'
    ];

    public function inventoriesDetails()
    {
        return $this->hasMany(InventoryDetail::class, 'product_id', 'id');
    }

    public function inventories()
    {
        return $this->belongsToMany(Inventory::class, 'inventories_details', 'product_id', 'inventory_id');
    }

    public function locations()
    {
        // Relation à travers le modèle ProductLocation
        $location = Location::find(my_location()->id); 
        if ((int) $location->is_parent == 1) {
            return $this->hasMany(ProductLocation::class, 'product_id');
        } else {
            return $this->hasMany(ProductLocation::class, 'product_id')->where('location_id', $location->id);
        }
        
    }

    public function stock(){
        return $this->hasMany(ProductStock::class, "product_id", "id");
    }

    public function stock_hs()
    {
        return $this->hasMany(ProductHS::class, 'product_id', 'id');
    }

    public function stockStory(){
        return $this->hasMany(StockStory::class, 'product_id');
    }


    public function categories()
    {
        return $this->belongsToMany(Category::class, 'products_categories', 'product_id', 'category_id')->distinct();
    }
    
    public function dataprice()
    {
        return $this->hasMany(ProductCustomerPrice::class, 'product_id');
    }

    public function supplier_price() {
        return $this->hasMany(ProductSupplierPrice::class, 'product_id')
                    ->join('business_contacts', 'business_contacts.id', '=', 'products_suppliers_price.supplier_id')
                    ->orderByDesc('products_suppliers_price.created_at');
    }    

    public function category() {
        return $this->belongsToMany(Category::class, 'products_categories', 'product_id', 'category_id')
                    ->where('products_categories.pple', 1)->distinct();
    }
    
    public function unitedetail(){
        return $this->belongsTo(Unite::class, 'unite_id');
    }

}
