<?php

public static function products(array $filters = [], int $pagination = 0)
{
    $relations = ['categories', 'locations', 'category', 'unitedetail', 'stock', 'dataprice', 'supplier_price'];

    $query = Products::with($relations)
        ->join('products_locations', 'products_locations.product_id', '=', 'products.id')
        ->select(
            'products.*',
            'products_locations.status as location_status',
            'products_locations.reorder_level as location_reorder_level',
            'products_locations.description as location_description',
            'products_locations.position as location_position',
            'products_locations.price_variant as location_price_variant',
            'products_locations.is_tva_inclusive as location_is_tva_inclusive',
            'products_locations.tva_rate as location_tva_rate',
            'products_locations.cost_price as location_cost_price',
            'products_locations.cmup as location_cmup',
            'products_locations.frns_id as location_frns_id',
            'products_locations.frns as location_frns',
            'products_locations.frns_is_tva_inclusive as location_frns_is_tva_inclusive',
            'products_locations.frns_tva as location_frns_tva',
            'products_locations.frns_price as location_frns_price',
            'products_locations.purchase_price as location_purchase_price'
        )->distinct();

    $conditions = [];
    if (!empty($filters)) {
        self::applyFilters($query, $filters, $conditions);
    }

    // Récupérer les produits avec pagination ou sans
    $products = $pagination === 0 ? $query->get() : $query->paginate($pagination);

    // Précharger les relations et données nécessaires
    $products->load([
        'locations',
        'categories',
        'unitedetail',
        'stock' => function ($query) use ($conditions) {
            if (isset($conditions['products_locations.location_id'])) {
                $query->where('location_id', $conditions['products_locations.location_id']);
            }
        },
        'dataprice' => function ($query) use ($conditions) {
            if (isset($conditions['products_locations.location_id'])) {
                $query->where('location_id', $conditions['products_locations.location_id']);
            }
        },
        'supplier_price' => function ($query) {
            $query->orderByDesc('created_at');
        }
    ]);

    // Ajouter des champs supplémentaires directement sans boucles coûteuses
    $products->transform(function ($product) use ($conditions) {
        $product->emplacement = $product->locations->first();
        $product->stock = $product->stock->sum('stock'); // Calcul direct si plusieurs entrées
        $product->price = $product->dataprice->first()->price ?? 0;
        $product->dataprice_details = $product->dataprice;
        $product->supplier_prices = $product->supplier_price;

        return $product;
    });

    return $products;
}
