<?php

namespace modules\dashboard\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Services\ModuleService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use modules\catalogs\Models\ProductCategory;
use modules\catalogs\Models\Products;
use modules\catalogs\services\ProductService;
use modules\crm\Models\BusinessContact;
use modules\crm\services\CrmService;
use modules\location\Models\Location;
use modules\sales\Models\AccountingDocument;
use modules\sales\services\AccountingDocService;

class DashboardController extends Controller
{
    public function index(Request $request)
    {         
        if($request->ajax()){                
            $auth = Auth::user();
            if(is_null($auth->location_id)){
                $_locations = Location::all();
            }else{
                $_locations = Location::where('id', $auth->location_id)->get();
            }  
            
            $customers = BusinessContact::where("category", "customer")->count();
            $new_customers = BusinessContact::where("category", "customer")
                            ->whereDate('created_at', '>=', date_now()->subDays(15))
                            ->count();
            $products = Products::count();
            $newproducts = Products::whereDate('created_at', '>=', date_now()->subDays(15))->count();            

            $tab = $request->tab;
            
            if($tab == 'activity'){                
                $return = [
                    'auth' => Auth::user(),
                    'customers' => [
                        'count' => $customers,
                        'newest' => $new_customers
                    ],
                    'products' => [
                        'count' => $products,
                        'newest' => $newproducts,
                    ],
                    'locations' => [
                        'mine' => Location::find($auth->location_id),
                        'count' => Location::count(),
                        'data' => $this->locationData($_locations)
                    ],
                    'documents' => [
                        'invoice' => $this->documentData('invoice', [3, 4]),
                        'quote' => $this->documentData('quote', [7, 8]),
                    ]
                ];
            }else{                
                $report = (new AccountingDocService())->customerInvoiceReport($_locations);

                $return = [                
                    'auth' => Auth::user(),      
                    'locations' => [
                        'mine' => Location::find($auth->location_id),
                        'count' => Location::count(),
                        'data' => $report
                    ],
                    'sales' => [
                        'data' => ProductService::getMonthlyCA($_locations),
                        'location' => ProductService::getSalesCountByLocation()
                    ],
                ];
            }
            
            return response()->json($return);
        }
               
        return view('dashboard::index');
    }

    public function locationData($locations){
        $data = [];
        foreach($locations as $location){
            $products = ProductService::getTopSoldProducts($location->id);
            $lowStock = ProductService::getLowStockProducts($location->id);

            $data[$location['id']] = [
                'id' => $location['id'],
                'location' => $location['title'],
                'manage_stock' => $location['stock_management'],
                'products' => [
                    'top' => $products,
                    'lowStock' => $lowStock->count()
                ]
            ];
        }

        return $data;
    }

    public function documentData(string $type, array $status){
        $months = range(1, 12);
     
        $documents = [];
        foreach ($months as $m) {            
            $documents[$m] = count((new AccountingDocService())->status([
                'begin' => date_now()->format('Y'),
                'end' => date_now()->format('Y'),
                'month' => $m
            ], [
                'accounting_document_status_id' => $status,
                'document_type' => $type,
                'document_for' => 'customer'
            ]));
        }

        return $documents;
    }
    
}
