<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    protected $tables = [
        'business_contacts',
        'products',
        'users'
    ];

    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('locations', function (Blueprint $table) {
            $table->id();            
            $table->unsignedBigInteger('parent_id')->nullable()->after('id'); // Ajoute la colonne
            $table->enum('type', ['site', 'depot', 'emplacement'])->nullable();
            $table->string('title');            
            $table->text('description')->nullable();
            $table->string('slug');            
            $table->enum('status', ['active', 'inactive'])->nullable();
            $table->timestamps();
            $table->foreign('location_id')
                        ->references('id')->on('locations')
                        ->onDelete('cascade');
        });

        foreach ($this->tables as $tableName) {
            // Vérifier si la table existe
            if (Schema::hasTable($tableName)) {
                // Modifier la table pour ajouter la colonne 'location_id' et la clé étrangère
                Schema::table($tableName, function (Blueprint $table) use ($tableName) {
                    // Vérifier si la colonne 'location_id' existe déjà
                    if (!Schema::hasColumn($tableName, 'location_id')) {
                        $table->unsignedBigInteger('location_id')->nullable()->after('id'); // Ajoute la colonne
                    }

                    // Ajouter la clé étrangère
                    $table->foreign('location_id')
                        ->references('id')->on('locations')
                        ->onDelete('set null'); // Définir le comportement onDelete
                });
            }
        }
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('locations');

        foreach ($this->tables as $tableName) {
            // Vérifier si la table existe
            if (Schema::hasTable($tableName)) {
                Schema::table($tableName, function (Blueprint $table) use ($tableName) {
                    // Supprimer la clé étrangère si elle existe
                    $table->dropForeign(['location_id']);
                    
                    // Supprimer la colonne 'location_id' si elle existe
                    if (Schema::hasColumn($tableName, 'location_id')) {
                        $table->dropColumn('location_id');
                    }
                });
            }
        }

    }
};
