<?php

namespace modules\sales\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use modules\crm\Models\BusinessContact;
use modules\location\Models\Location;

class purchaseDocument extends Model
{
    use HasFactory;

    protected $table = "purchases_documents";
    protected $fillable = [
        'location_id',
        'location',
        "document_type",
        "link_to",
        "document_id",
        "numero",
        "reference",
        "document_date",
        "document_release_date",
        "customer_id",
        "customer",
        "customer_email",
        "customer_phone",
        "customer_address",
        "discount_by",
        "discount_rate",
        "discount_price",
        "tva_rate",
        "tva_price",
        "total_ht",
        "total_ttc",
        "slug",
        "validate",
        "user_id",
        "username",
        "edited_by",
        "edited_name",
        "document_for"
    ];

    public function customer(){        
        return $this->belongsTo(BusinessContact::class, 'customer_id');
    }

    public function status() {
        return $this->hasMany(AccountingDocStatusLog::class, 'document_id', 'id')->orderByDesc('created_at');
    }

    public function stories(){
        return $this->hasMany(AccountingDocumentLog::class, 'document_id', 'id')
                ->select(
                    'documents_logs.*', 
                    'documents_status.title as status_name', 
                    'documents_status.icon as status_icon', 
                    'documents_status.background as background', 
                    'documents_status.color as color',
                )
                #->join('documents_logs', 'documents_logs.id', '=', 'documents_logs.documents_logs_id')
                ->join('documents_status', 'documents_status.id', '=', 'documents_logs.document_status_id')
                ->orderByDesc('documents_logs.created_at');
    }

    public function invoice_type()
    {
        return $this->belongsTo(InvoiceType::class, 'id', 'invoice_id');
    }


    /*public function details(){
        return $this->hasMany(AccountingDocumentDetail::class, 'document_id', 'id');
    }*/

    public function details()
    {
        return $this->hasMany(AccountingDocumentDetail::class, 'document_id', 'id')
            ->with(['category']);
    }

    public function location(){
        return $this->belongsTo(Location::class, 'location_id');
    }
    
    public function payments(){
        return $this->hasMany(AccountingDocumentPayment::class, 'document_id', 'id');
    }

}