<?php

namespace modules\sales\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use modules\catalogs\Models\ProductCustomerPrice;
use modules\catalogs\Models\ProductLocation;
use modules\catalogs\services\ProductCustomerService;
use modules\crm\Models\BusinessContact;
use modules\crm\services\CrmService;
use modules\location\Models\Location;
use modules\sales\Models\Caisse;
use modules\sales\Models\CaisseStatus;
use modules\sales\Models\Cart;
use modules\sales\Models\CartDetail;
use modules\sales\Models\ReceiptDiscount;
use modules\sales\services\BasketService;
use modules\sales\services\CaisseService;

class basketController extends Controller
{
    protected $basket;
    public function __construct(BasketService $basket)
    {
        $this->basket = $basket;
    }

    public function load(Request $request){
        if(Session::has('vente_token')){
            $token = Session::get('vente_token');            
            $cart = Cart::where('token', $token)->with('details.product')->first();

            return response()->json([
                "status" => 'success',                
                "cart" => $cart
            ]);
        }

        return response()->json([
            'status' => 'error',
            'message' => "Erreur, rafraichir la page"
        ]);
    }

    public function store(Request $request) {
        if(!Session::has('has_delivery')){
            Session::put('has_delivery', $request->delivery);
        }
        
        $location = my_location();

        $rep = $this->basket->store(
            $request, 
            $location->id
        );

        if($rep['status'] == 'success'){
            $cart = Cart::where('id', $rep['cartId'])->with('details.product')->first();            
            $response = [
                "status" => 'success',
                "message" => $rep["message"],
                "cart" => $cart
            ];
        }else{
            $response = [
                "status" => 'error',
                "message" => "Erreur"
            ];
        }   
        

        return response()->json($response);
    }

    public function destroy(int $id){
        $detail = CartDetail::find($id);
        $detail->delete();

        $cart = Cart::where('id', $detail->cart_id)->with('details.product')->first();            
        $response = [
            "status" => 'success',
            "message" => 'Ligne supprimé avec succès',
            "cart" => $cart
        ];

        return response()->json($response);
    }

    public function discount(Request $request){
        if(!Session::has('has_discount')){
            Session::put('has_discount', true);
            Session::save();
        }

        $token = Session::get('vente_token');
        #dd($request->all());

        $by = $request->discount_by['value'];
        $type = $request->discount_type;
        $value = $request->qty;
        
        // Handle different discount types using a switch statement
        switch ($type) {
            case 'by_product':
                $id = $request->id;
                $cart = Cart::where('token', $token)->with(['details'])->first();                
                $detail = $cart->details->where('id', $id)->first();                
                $qty = $detail->qty;

                $product = (new ProductCustomerService())->getPrice(
                    $cart->customer_id, #customer_id
                    $detail->product_id, #product_id
                    $cart->location_id, #location
                    $qty, #location
                );
                
                $price = $product->price;
                if($by == 'percent'){
                    $rate = (float)$value / 100;
                    $discountprice = (float)$price * $rate;                                    
                    $percent = $value;
                }else{
                    $discountprice = (float)$value;
                    $percent = ($discountprice / $price) * 100;
                }

                $detail->discount_by = $by == 'percent' ? 'percent' : 'price';
                $detail->discount_type = 'product';
                $detail->discount_of = 'price_unit';
                $detail->discount = $percent;
                $detail->discount_price = $discountprice;
                
                $delivery = $detail->delivery_price * $qty;
                $newprice = $price - $discountprice;
                $newtotalht = (float)$newprice * $qty;                

                $tva = $detail->tva;                
                $tva_price = ($newtotalht * $tva) / 100; // Calculate TVA price

                $detail->price = $price;
                $detail->total_price_ht = $newtotalht;
                $detail->tva_price = $tva_price; // Assign TVA price

                $newttc = $newtotalht + $delivery + $tva_price; // Include TVA price in total TTC

                $detail->total_price_ttc = $newttc;

                $detail->save();
                
                if(is_null(ReceiptDiscount::find($detail->product_id))){
                    ReceiptDiscount::create([
                        'token' => $token,
                        'product_id' => $detail->product_id,
                        'discount_type' => 'by_product',
                        'created_at' => date_now(),
                        'updated_at' => date_now(),
                    ]);
                }


                $cart = Cart::where('token', $token)->with(['details.product'])->first();
                return response()->json([
                    'status' => 'success',
                    'cart' => $cart
                ]);

                break;
            case 'by_sale':
                // Logic for discount by sale
                break;

            case 'item_offered':
                $id = $request->id;
                $detail = CartDetail::find($id);

                $detail->discount_by = $by;
                $detail->discount_type = 'offered';
                $detail->discount_of = 'price_unit';
                $detail->price = 0;
                $detail->discount = 0;
                $detail->discount_price = 0;
                $detail->tva = 0;
                $detail->tva_price = 0;
                $detail->delivery_price = 0;
                $detail->delivery_price_total = 0;

                $detail->save();
                break;

            case 'sale_offered_without_price':
                // Logic for sale offered without price
                break;

            case 'sale_offered_with_price':
                // Logic for sale offered with price
                break;

            default:
                // Handle unknown discount type
                throw new \InvalidArgumentException("Invalid discount type: $type");
        }


    }

    public function delivery(Request $request){
        try {
            Session::put('has_delivery', $request->delivery);
            Session::save();

            if(Session::has("vente_token")){
                $location = $request->location;
                $token = Session::get("vente_token");
                
                $cart = Cart::where('token', $token)->with(['details.product'])->first();
                $productIds = $cart->details->pluck('product_id')->unique(); // Récupérer tous les IDs des produits
                $products = ProductLocation::where('location_id', $location['id'])
                    ->whereIn('product_id', $productIds)
                    ->get()
                    ->keyBy('product_id'); // Associer les produits par leur ID

                // Calculer la somme de delivery_price_total après mise à jour des détails
                $totalDeliveryPrice = 0;                
                foreach ($cart->details as $detail) {                    
                    if (isset($products[$detail->product_id])) {
                        $product = $products[$detail->product_id];
                        
                        #dd($product->delivery_status == 'active' && $request->delivery);

                        if ($product->delivery_status == 'active' && $request->delivery) {
                            $delivery_price = $product->delivery_price;
                            $detail->delivery_price = $delivery_price;
                            $detail->delivery_price_total = (float)$detail->qty * (float)$delivery_price;
                            $detail->save();

                            // Ajouter la valeur à la somme totale
                            $totalDeliveryPrice += $detail->delivery_price_total;
                        }else{
                            $detail->delivery_price = 0;
                            $detail->delivery_price_total = 0;
                            $detail->save();
                        }
                    }
                }

                // Mettre à jour le total du panier avec la somme des frais de livraison
                $cart->delivery_price = $totalDeliveryPrice;
                $cart->save();
                return response()->json([
                    'status' => 'success',
                    "cart" => $cart
                ]);
            }else{                
                $token = generateString(60);
                Session::put("vente_token", $token);
            }
        } catch (\Throwable $th) {
            throw $th;
        }
    }
        
}