<?php

namespace modules\sales\services;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use modules\catalogs\services\ProductCustomerService;
use modules\catalogs\services\ProductService;
use modules\crm\Models\BusinessContact;
use modules\location\Models\Location;
use modules\sales\Models\Cart;
use modules\sales\Models\CartDetail;

class BasketService
{
    public function store(Request $request, int $location_id){        
        if(Session::has("vente_token")){
            $token = Session::get("vente_token");
        }else{
            $token = generateString(60);
            Session::put("vente_token", $token);
        }
        
        $user = Auth::user();

        $caisseOpenId = Session::get('caisse_open_id');

        $customer = $request->customer;
        $customerName = $customer['title'];

        $location = Location::find($location_id);        
        $cart = Cart::where("token", $token)->first();        

        if(is_null($cart)){
            $cart = Cart::create([
                'caisse_open_id' => $caisseOpenId,
                'location_id' => $location_id,
                'location' => $location->title,
                'customer_id' => $customer['id'],
                'customer' => $customerName,
                'status' => 'pending',                
                'token' => $token,
                'user_id' => $user->id,
                'user' => $user->name,
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);
        }else{
            $cart->customer_id = $customer['id'];
            $cart->customer = $customerName;
            $cart->save();
        }                

        $product_id = $request->id;
        $product = ProductService::products(['location' => $location_id, 'id' => $product_id])->first();          

        $qty = $request->qty;        

        //$price = $product->price;
        $productPrice = (new ProductCustomerService())->getPrice(
            $customer['id'], #customer_id
            $product_id, #product_id
            $location_id, #location
            $qty, #location
        );        
        $price = $productPrice->price;

        if($customer['group']['rate_type'] != 'none'){
            $query = $product->dataprice->where('group_id', $customer['group_id']);
            if((int)$product->price_variant == 1){
                $query = $query->where("qty_min", "<=", $qty)->where('qty_max', '>=', $qty);
            }

            $price = $query->first()->price;
        }

        $delivery_price = 0;
        if(Session::has('has_delivery') && Session::get('has_delivery')){
            $delivery_price = (float)$product->delivery_price;
        }

        $hastva = false;
        $tva = 0;
        if((int)$product->locations[0]->is_tva_inclusive == 1){
            $hastva = true;
            $tva = $product->locations[0]->tva_rate;
        }        

        $cartDetail = CartDetail::where('product_id', $product_id)->whereHas('cart', function($query) use ($token){
            $query->where('token', $token);
        })->get();

        if((int)$product->stock_management == 1){
            $stock = $product->stock[0]->stock;
            
            //CHECK IF STOCK AVAILABLE                        
            $cartQty = $cartDetail->sum('qty');            
            if($qty > ((float)$stock - (float)$cartQty)){
                return [
                    "status" => "error",
                    "message" => "low stock",
                    "product" => $product                    
                ];
            }            
        }
#==================================================================================================================================

        //PRICE
        $price_total = (float)$qty * (float)$price;
        $delivery_total = (float)$qty * (float)$delivery_price;            
        //PRICE            

        if(count($cartDetail) > 0){
            $discount = (float)$cartDetail[0]->discount;
            $discount_price = $price_total * ($discount / 100);

            $pricetva = 0;
            if($hastva){
                $pricetva = ((double)$price_total - $discount_price) * ($tva / 100);
            }

            $ttc = $price_total - $discount_price + $pricetva;
            
            CartDetail::where([
                'product_id' => $product_id,
                'cart_id' => $cart->id
            ])->update([
                "qty" => $qty,                                        
                'stock_out' => $qty,
                'product_stock' => (int)$product->stock_management == 1 ? $stock : 0,
                'price' => $price,
                'tva' => $tva,
                'tva_price' => $pricetva,
                'discount_price' => $discount_price,
                'total_price_ht' => $price_total,
                'total_price_ttc' => $ttc,
                'delivery_price' => $delivery_price,
                'delivery_price_total' => $delivery_total,
            ]);
        }else{ 
            $pricetva = 0;
            if($hastva){
                $pricetva = (double)$price_total * ($tva / 100);
            }
            $ttc = $price_total - $pricetva;

            CartDetail::create([
                "cart_id" => $cart->id,
                'product_id' => $product_id,
                'product_title' => $product->title,
                'product_out_reference' => $product->reference,
                'product_image' => $product->image,

                'product_id_out' => $product_id,
                'product_out_title' => $product->title,
                'product_reference' => $product->reference,                    
                'unite_id' => $product->unite_id,                    
                'unite' => $product->unite,                    
                
                "qty" => $qty,
                'stock_out' => $qty,
                'product_stock' => (int)$product->stock_management == 1 ? $stock : 0,
                'price' => $price,
                'tva' => $tva,
                'tva_price' => $pricetva,
                'total_price_ht' => $price_total,
                'total_price_ttc' => $ttc,

                'delivery_price' => $delivery_price,
                'delivery_price_total' => $delivery_total,
                
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);
        }
                    
        return [
            "status" => "success",
            "cartId" => $cart->id,
            "message" => "added successfully"
        ];

    }

    public function details(array $data = []){
        $_ht = 0;
        $_qte = 0;
        $_tva = 0;
        $_remise = 0;
        $_delivery = 0;
        $_ttc = 0;
        $obs = "";
        $_data = $this->getDetails($data);

        foreach($_data as $item){

            $price = $item->price;
            $quantity = $item->quantity;
            $discount = $item->discount;
            $discount_price = 0;
            $tva = $item->tva;
            $prix_tva = 0;
            $delivery_price = 0;

            $_qte += $quantity;

            if($item->discount_of == "price_unit"){
                if($item->discount_by == "values"){
                    $price = (float)$item->price - (float)$item->discount_price;
                }
                if($item->discount_by == "percent"){
                    $discount_price = (float)$item->price * (float)$item->discount / 100;
                    $price = (float)$item->price - (float)$discount_price;
                }

                $discount = 0;
                $discount_price = 0;
            }else{
                $discount = $item->discount;
                $discount_price = $item->discount_price;
            }

            $prix_total = (float)$price * (float)$quantity;
            dd($item);
            $_ht += $prix_total;
            $_remise += (float)$discount_price;

            if((float)$tva != 0){
                $prix_tva = (float)$prix_total * ((float)$tva / 100);
            }
            $_tva += $prix_tva;

            if((float)$item->delivery_price > 0){
                $delivery_price = $item->delivery_price;
            }

            $total_delivery_price = (float)$delivery_price * (float)$quantity;
            $_delivery += $total_delivery_price;
            $prix_total_ttc = (float)$prix_total - (float)$discount_price + (float)$prix_tva + $total_delivery_price;
            $_ttc += $prix_total_ttc;

            if(!is_null($item->observation)){
                $obs .= "- " . $item->observation."\r\n";
            }
        }

        $details = [
            "list" => $_data,
            "qte" => $_qte,
            "ht" => $_ht,
            "remise" => $_remise,
            "remise_percent" => 0,
            "tva" => $_tva,
            "delivery" => $_delivery,
            "ttc" => $_ttc,
            "obs" => $obs
        ];
        dd($_ht);
        
        return $details;
    }

    public function getDetails(array $data = [])
    {
        $det = Cart::with(['details.product']);
        if(!empty($data)){
            if(isset($data["id"])){
                $det->where("id", $data['id']);
            }

            if(isset($data["token"])){
                $det->where("token", $data['token']);
            }

            if(isset($data['product_id'])){
                $det->where("caisse_basket.product_id", $data['product_id']);
            }
        }

        return $det->orderBy("created_at")->get();
    }
}