<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('receipts', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('caisse_status_id')->nullable();
            $table->unsignedBigInteger('location_id')->nullable();
            $table->string('location')->nullable();
            $table->unsignedBigInteger('customer_id')->nullable();
            $table->string('customer')->nullable();
            $table->string('customer_email')->nullable();
            $table->string('customer_phone')->nullable();
            $table->string('customer_address')->nullable();            
            $table->enum('status', ['draft', 'validate'])->default('draft');
            $table->integer('numero')->default(0);
            $table->string('reference')->unique();
            $table->boolean('has_discount')->default(false);
            $table->double('discount')->default(0);
            $table->double('total_ht', 12, 2)->default(0);
            $table->double('discount_price', 12, 2)->default(0);
            $table->double('tva', 12, 2)->default(0);
            $table->double('tva_price', 12, 2)->default(0);            
            $table->boolean('has_delivery')->default(false);
            $table->double('delivery_price', 12, 2)->default(0);
            $table->double('total_ttc', 12, 2)->default(0);
            $table->double('acompte', 12, 2)->default(0);
            $table->text('observation')->nullable();
            $table->string('token')->unique();
            $table->json('document_term')->nullable();
            $table->json('user');
            
            // Ajoute les clés étrangères
            $table->foreign('caisse_status_id')->references('id')->on('caisses_status')->onDelete('set null');
            $table->foreign('location_id')->references('id')->on('locations')->onDelete('set null');
            $table->foreign('customer_id')->references('id')->on('business_contacts')->onDelete('set null');
            
            $table->timestamps();
        });
        
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('receipts');
    }
};
