<?php

namespace modules\stocks\Models;

use Illuminate\Database\Eloquent\Model;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use modules\catalogs\Models\Products;
use modules\catalogs\services\ProductService;
use modules\location\Models\Location;

use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\View;

class Inventory extends Model
{
    use HasFactory;

    protected $table = "inventories";
    protected $fillable = [
        'location_id',
        'location',
        'numero',
        'reference',
        'inventory_date',
        'status',
        'user_id',
        'username',
        'slug',
        'validate'
    ];

    public function location(){
        return $this->belongsTo(Location::class, 'location_id');
    }

    public function details(){
        return $this->hasMany(InventoryDetail::class, 'inventory_id');
    }

    public function products()
    {
        return $this->belongsToMany(Products::class, 'inventories_details', 'inventory_id', 'product_id');
    }

    protected $cols = [
        [
            'title' => 'Référence',
            'width' => '7%',
            'align' => 'left',
            'weight' => 'bold'
        ],
        [
            'title' => 'Désignation',
            'width' => '20%',
            'align' => 'left',
            'weight' => 'bold'
        ],
        [
            'title' => 'Qté',
            'width' => '7%',
            'align' => 'center',
            'weight' => 'bold'
        ],
        [
            'title' => 'U',
            'width' => '5%',
            'align' => 'center',
            'weight' => 'bold'
        ],
        [
            'title' => 'PR Unitaire',
            'width' => '12%',
            'align' => 'right',
            'weight' => 'bold'
        ],
        [
            'title' => 'Valeur',
            'width' => '12%',
            'align' => 'right',
            'weight' => 'bold'
        ],
        [
            'title' => 'Ajustement',
            'width' => '10%',
            'align' => 'center',
            'weight' => 'bold'
        ],
        [
            'title' => 'PR Ajusté',
            'width' => '14%',
            'align' => 'right',
            'weight' => 'bold'
        ],
    ];

    public function printdocument($slug){
        $inventory = Inventory::where('slug', $slug)->first(); // Récupère l'inventaire
        $location_id = $inventory->location_id; // Récupère l'ID de l'emplacement

        $detail = $inventory->toArray();

        if($inventory->status == 'inprogress'){
            $filter['location'] = $location_id;
            $filter['with'] = 'inventories-details';
            $filter['inventory-slug'] = $slug;                        

            $detail['details'] = ProductService::products($filter, 0)->toArray();
        }else{
            $rep = $inventory->details()->with([
                'product.categories',
                'product.locations' => function ($query) use ($location_id) {
                    $query->where('location_id', $location_id);
                }
            ])->get();                                   
            
            $detail['details'] = $rep->toArray(); // Remplacer `details` par les données paginées
        }     

        #dd($detail);
        
        $name = "Inventaire-".date('dmY').".pdf";
        $path = public_path("pdf/inventories/matrice");        
        $location = Location::find($location_id);
        $doc['document_logo'] = $location->logo;
        $doc['document_header'] = is_null($location->header) ? "<h3 class='docTitle' style='float: right; font-size: 26px!important;'>".$location->title."</h3>" : $location->header;
        $doc['document_footer'] = $location->footer;

        $pdf = PDF::loadView('documents.inventory.detail', [
            'cols' => $this->cols,
            'doc' => $doc,
            'detail' => $detail
        ]);

        $pdf->setOptions([
            'isHtml5ParserEnabled' => true,
            'isRemoteEnabled' => true,
            'isPhpEnabled' => true,
        ]);

        // Add footer using DomPDF callbacks
        $pdf->setPaper('a4');
        $pdf->output();
        $pdf->getDomPDF();
    
        $footerHtml = View::make('documents.partials.footer', [
            'footer' => nl2br($location->footer)
        ])->render();

        // Convertir le HTML en texte brut
        $footer_text = strip_tags($footerHtml);
        #dd($footer_text, $footerHtml);
        
        // Ajouter le pied de page
        $pdf->getDomPDF()->getCanvas()->page_script(function ($pageNumber, $pageCount, $canvas, $fontMetrics) use ($footerHtml) {
            // Convertir <br> en sauts de ligne pour DomPDF
            $footer_text = strip_tags($footerHtml);  // Enlever les balises HTML
            $lines = explode("\n", $footer_text);    // Diviser le texte en lignes par saut de ligne
            
            $size = 8;
            $width = $canvas->get_width();
            $height = $canvas->get_height();
            
            // Charger une police intégrée
            $font = $fontMetrics->getFont("helvetica", "normal");
            
            // Dessiner la ligne du pied de page
            $canvas->line(20, $height - 45, $width - 20, $height - 45, array(0, 0, 0), 0.1); // Ligne horizontale du bas
            
            foreach ($lines as $index => $line) {
                $text = trim($line);
                if ($text === '') {
                    continue; // Sauter les lignes vides
                }
                $textWidth = $fontMetrics->getTextWidth($text, $font, $size); // Largeur du texte
                $x = ($width - $textWidth) / 2; // Centrer le texte horizontalement
                $y = $height - 20 - ($index * 10); // Ajuster la position verticale pour chaque ligne
                $canvas->text($x, $y, $text, $font, $size, [0, 0, 0]);
            }
        });
    
        if (!File::exists("$path/$name")) {
            if (!File::isDirectory($path)) {
                File::makeDirectory($path, 0777, true, true);
            }
                    
            $pdf->save("$path/$name");
        }

        return [
            'pdf' => $pdf,
            'name' => $name
        ];
        
    }
    
    public function printmatrice(Location $location){        
        $filter = [
            'location' => $location->id
        ];
        $products = ProductService::products($filter, 0);        
        $name = "Inventaire-".date('dmY').".pdf";
        $path = public_path("pdf/inventories/matrice");        
        
        $doc['document_logo'] = $location->logo;
        $doc['document_header'] = is_null($location->header) ? "<h3 class='docTitle' style='float: right; font-size: 26px!important;'>".$location->title."</h3>" : $location->header;
        $doc['document_footer'] = $location->footer;

        $pdf = PDF::loadView('documents.inventory.matrice', [
            'cols' => $this->cols,
            'doc' => $doc,
            'products' => $products,            
        ]);

        $pdf->setOptions([
            'isHtml5ParserEnabled' => true,
            'isRemoteEnabled' => true,
            'isPhpEnabled' => true,
        ]);

        // Add footer using DomPDF callbacks
        $pdf->setPaper('a4');
        $pdf->output();
        $pdf->getDomPDF();
    
        $footerHtml = View::make('documents.partials.footer', [
            'footer' => nl2br($location->footer)
        ])->render();

        // Convertir le HTML en texte brut
        $footer_text = strip_tags($footerHtml);
        #dd($footer_text, $footerHtml);
        
        // Ajouter le pied de page
        $pdf->getDomPDF()->getCanvas()->page_script(function ($pageNumber, $pageCount, $canvas, $fontMetrics) use ($footerHtml) {
            // Convertir <br> en sauts de ligne pour DomPDF
            $footer_text = strip_tags($footerHtml);  // Enlever les balises HTML
            $lines = explode("\n", $footer_text);    // Diviser le texte en lignes par saut de ligne
            
            $size = 8;
            $width = $canvas->get_width();
            $height = $canvas->get_height();
            
            // Charger une police intégrée
            $font = $fontMetrics->getFont("helvetica", "normal");
            
            // Dessiner la ligne du pied de page
            $canvas->line(20, $height - 45, $width - 20, $height - 45, array(0, 0, 0), 0.1); // Ligne horizontale du bas
            
            foreach ($lines as $index => $line) {
                $text = trim($line);
                if ($text === '') {
                    continue; // Sauter les lignes vides
                }
                $textWidth = $fontMetrics->getTextWidth($text, $font, $size); // Largeur du texte
                $x = ($width - $textWidth) / 2; // Centrer le texte horizontalement
                $y = $height - 20 - ($index * 10); // Ajuster la position verticale pour chaque ligne
                $canvas->text($x, $y, $text, $font, $size, [0, 0, 0]);
            }
        });
    
        if (!File::exists("$path/$name")) {
            if (!File::isDirectory($path)) {
                File::makeDirectory($path, 0777, true, true);
            }
                    
            $pdf->save("$path/$name");
        }

        return [
            'pdf' => $pdf,
            'name' => $name
        ];
    }

}