<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('stocks_transfert', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('source_location_id'); // ID de l'entrepôt source
            $table->unsignedBigInteger('destination_location_id'); // ID de l'entrepôt de destination
            $table->string('slug')->unique(); // Référence unique de la demande
            $table->date('requested_at'); // Date de la demande
            $table->date('expected_transfer_date')->nullable(); // Date prévue du transfert
            $table->text('notes')->nullable(); // Notes ou commentaires supplémentaires
            $table->enum('status', ['pending', 'approved', 'rejected', 'transferred', 'cancelled'])->default('pending'); // Statut de la demande
            $table->unsignedBigInteger('user_id'); // ID de l'utilisateur ayant créé la demande            
            $table->string('username');
            $table->unsignedBigInteger('approved_by')->nullable(); // ID de l'utilisateur ayant approuvé la demande
            $table->string('approved_username')->nullable();

            // Clés étrangères
            $table->foreign('source_location_id')->references('id')->on('locations')->onDelete('cascade');
            $table->foreign('destination_location_id')->references('id')->on('locations')->onDelete('cascade');
            $table->foreign('user_id')->references('id')->on('users')->onDelete('cascade');
            $table->foreign('approved_by')->references('id')->on('users')->onDelete('cascade');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('stocks_transfert');
    }
};
